@@ -5,5 +5,5 @@ head.duckplyr_df <- function(x, n = 6L, ...) {
   rel <- duckdb_rel_from_df(x)
   out_rel <- rel_limit(rel, n)
   out <- rel_to_df(out_rel)
-  dplyr_reconstruct_dispatch(out, x)
+  dplyr_reconstruct(out, x)
 }
