@@ -12,12 +12,14 @@
 #' @param x An object.
 #' @param class Classes added in front of the `"relational_relexpr"` base class.
 #'
-#' @name expr
+#' @name new_relexpr
 #' @return an object of class `"relational_relexpr"`
 #' @export
 #' @examples
-#' relexpr_set_alias(alias = "my_predicate",
-#'   relexpr_function("<",
+#' relexpr_set_alias(
+#'   alias = "my_predicate",
+#'   relexpr_function(
+#'     "<",
 #'     list(
 #'       relexpr_reference("my_number"),
 #'       relexpr_constant(42)
@@ -35,7 +37,7 @@ new_relexpr <- function(x, class = NULL) {
 #' @param name The name of the column or function to reference.
 #' @param rel The name of the relation to reference.
 #' @param alias An alias for the new expression.
-#' @rdname expr
+#' @rdname new_relexpr
 #' @return an object of class `"relational_relexpr"`
 #' @export
 relexpr_reference <- function(name, rel = NULL, alias = NULL) {
@@ -50,7 +52,7 @@ relexpr_reference <- function(name, rel = NULL, alias = NULL) {
 #' `relexpr_constant()` wraps a constant value.
 #'
 #' @param val The value to use in the constant expression.
-#' @rdname expr
+#' @rdname new_relexpr
 #' @return an object of class `"relational_relexpr"`
 #' @export
 relexpr_constant <- function(val, alias = NULL) {
@@ -65,7 +67,7 @@ relexpr_constant <- function(val, alias = NULL) {
 #' The arguments to this function are a list of other expression objects.
 #'
 #' @param args Function arguments, a list of `expr` objects.
-#' @rdname expr
+#' @rdname new_relexpr
 #' @return an object of class `"relational_relexpr"`
 #' @export
 relexpr_function <- function(name, args, alias = NULL) {
@@ -84,7 +86,7 @@ relexpr_function <- function(name, args, alias = NULL) {
 #' @param order_bys which variables to order results by (list).
 #' @param offset_expr offset relational expression.
 #' @param default_expr default relational expression.
-#' @rdname expr
+#' @rdname new_relexpr
 #' @export
 relexpr_window <- function(
     expr,
@@ -92,8 +94,7 @@ relexpr_window <- function(
     order_bys = list(),
     offset_expr = NULL,
     default_expr = NULL,
-    alias = NULL
-) {
+    alias = NULL) {
   stopifnot(inherits(expr, "relational_relexpr"))
   stopifnot(is.list(partitions))
   stopifnot(is.list(order_bys))
@@ -118,7 +119,7 @@ relexpr_window <- function(
 #' `relexpr_set_alias()` assigns an alias to an expression.
 #'
 #' @param expr An `expr` object.
-#' @rdname expr
+#' @rdname new_relexpr
 #' @return an object of class `"relational_relexpr"`
 #' @export
 relexpr_set_alias <- function(expr, alias = NULL) {
